.. include:: ../README.rst

Table of Contents
=================

.. toctree::
    :maxdepth: 4
    :hidden:

    self

.. toctree::
    :caption: Examples

    examples

.. toctree::
    :caption: API Reference
    :maxdepth: 3

    api

.. toctree::
    :caption: Tutorials

    Adafruit seesaw <https://learn.adafruit.com/adafruit-seesaw-atsamd09-breakout/circuitpython-wiring-test>

    Make it Move with Crickit <https://learn.adafruit.com/make-it-move-with-crickit>

    Joy Featherwing <https://learn.adafruit.com/joy-featherwing>

    Adafruit Mini TFT with Joystick Featherwing <https://learn.adafruit.com/adafruit-mini-tft-featherwing>

    Adafruit I2C QT Rotary Encoder <https://learn.adafruit.com/adafruit-i2c-qt-rotary-encoder/python-circuitpython>

    Adafruit STEMMA Soil Sensor - I2C Capacitive Moisture Sensor <https://learn.adafruit.com/adafruit-stemma-soil-sensor-i2c-capacitive-moisture-sensor>

    Discord and Slack Connected Smart Plant with Adafruit IO Triggers <https://learn.adafruit.com/discord-and-slack-connected-smart-plant-with-adafruit-io-triggers>

.. toctree::
    :caption: Related Products

    Adafruit ATSAMD09 Breakout with seesaw  <https://www.adafruit.com/product/3657>

    Adafruit CRICKIT for Circuit Playground Express <https://www.adafruit.com/product/3093>

    Adafruit Joy FeatherWing for all Feathers <https://www.adafruit.com/product/3632>

    Adafruit Mini Color TFT with Joystick FeatherWing <https://www.adafruit.com/product/3321>

    Adafruit I2C QT Rotary Encoder with NeoPixel  <https://www.adafruit.com/product/4991>

    Adafruit STEMMA Soil Sensor - I2C Capacitive Moisture Sensor <https://www.adafruit.com/product/4026>

.. toctree::
    :caption: Other Links

    Download <https://github.com/adafruit/Adafruit_CircuitPython_seesaw/releases/latest>
    CircuitPython Reference Documentation <https://circuitpython.readthedocs.io>
    CircuitPython Support Forum <https://forums.adafruit.com/viewforum.php?f=60>
    Discord Chat <https://adafru.it/discord>
    Adafruit Learning System <https://learn.adafruit.com>
    Adafruit Blog <https://blog.adafruit.com>
    Adafruit Store <https://www.adafruit.com>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
